@@ -23,16 +23,17 @@
 #include "krfbconfig.h"
 #include "rfbservermanager.h"
 #include <QtCore/QTimer>
-#include <QtGui/QApplication>
+#include <QApplication>
 #include <QtNetwork/QHostInfo>
-#include <KNotification>
-#include <KLocale>
-#include <KMessageBox>
+#include <QDebug>
+
+#include <KLocalizedString>
 #include <KUser>
 #include <KRandom>
 #include <KStringHandler>
-#include <KWallet/Wallet>
-#include <DNSSD/PublicService>
+#include <KWallet/KWallet>
+
+#include <dnssd/publicservice.h>
 using KWallet::Wallet;
 
 //static
@@ -42,7 +43,7 @@ InvitationsRfbServer *InvitationsRfbServer::instance;
 void InvitationsRfbServer::init()
 {
     instance = new InvitationsRfbServer;
-    instance->m_publicService = new DNSSD::PublicService(
+    instance->m_publicService = new KDNSSD::PublicService(
             i18n("%1@%2 (shared desktop)",
                 KUser().loginName(),
                 QHostInfo::localHostName()),
@@ -52,11 +53,16 @@ void InvitationsRfbServer::init()
     instance->setListeningPort(KrfbConfig::port());
     instance->setPasswordRequired(true);
 
-    instance->m_wallet = Wallet::openWallet(
-            Wallet::NetworkWallet(), 0, Wallet::Asynchronous);
-    if(instance->m_wallet) {
-        connect(instance->m_wallet, SIGNAL(walletOpened(bool)),
-                instance, SLOT(walletOpened(bool)));
+    if (KrfbConfig::noWallet()) {
+      instance->walletOpened(false);
+    }
+    else {
+      instance->m_wallet = Wallet::openWallet(
+              Wallet::NetworkWallet(), 0, Wallet::Asynchronous);
+      if(instance->m_wallet) {
+          connect(instance->m_wallet, &KWallet::Wallet::walletOpened,
+                  instance, &InvitationsRfbServer::walletOpened);
+      }
     }
 }
 
@@ -95,11 +101,11 @@ bool InvitationsRfbServer::start()
     return false;
 }
 
-void InvitationsRfbServer::stop(bool disconnectClients)
+void InvitationsRfbServer::stop()
 {
     if(m_publicService->isPublished())
         m_publicService->stop();
-    RfbServer::stop(disconnectClients);
+    RfbServer::stop();
 }
 
 void InvitationsRfbServer::toggleUnattendedAccess(bool allow)
@@ -111,8 +117,7 @@ InvitationsRfbServer::InvitationsRfbServer()
 {
     m_desktopPassword = readableRandomString(4)+"-"+readableRandomString(3);
     m_unattendedPassword = readableRandomString(4)+"-"+readableRandomString(3);
-    KSharedConfigPtr config = KGlobal::config();
-    KConfigGroup krfbConfig(config,"Security");
+    KConfigGroup krfbConfig(KSharedConfig::openConfig(),"Security");
     m_allowUnattendedAccess = krfbConfig.readEntry(
             "allowUnattendedAccess", QVariant(false)).toBool();
 }
@@ -120,11 +125,10 @@ InvitationsRfbServer::InvitationsRfbServer()
 InvitationsRfbServer::~InvitationsRfbServer()
 {
     stop();
-    KSharedConfigPtr config = KGlobal::config();
-    KConfigGroup krfbConfig(config,"Security");
+    KConfigGroup krfbConfig(KSharedConfig::openConfig(),"Security");
     krfbConfig.writeEntry("allowUnattendedAccess",m_allowUnattendedAccess);
-    if(m_wallet && m_wallet->isOpen()) {
-
+    if(!KrfbConfig::noWallet()) {
+      if (m_wallet && m_wallet->isOpen()) {
          if( (m_wallet->currentFolder()=="krfb") ||
                  ((m_wallet->hasFolder("krfb") || m_wallet->createFolder("krfb")) &&
                     m_wallet->setFolder("krfb")) ) {
@@ -132,6 +136,7 @@ InvitationsRfbServer::~InvitationsRfbServer()
              m_wallet->writePassword("desktopSharingPassword",m_desktopPassword);
              m_wallet->writePassword("unattendedAccessPassword",m_unattendedPassword);
          }
+       }
 
     } else {
         krfbConfig.writeEntry("desktopPassword",
@@ -170,9 +175,8 @@ void InvitationsRfbServer::walletOpened(bool opened)
 
     } else {
 
-        kDebug() << "Could not open KWallet, Falling back to config file";
-        KSharedConfigPtr config = KGlobal::config();
-        KConfigGroup krfbConfig(config,"Security");
+        qDebug() << "Could not open KWallet, Falling back to config file";
+        KConfigGroup krfbConfig(KSharedConfig::openConfig(),"Security");
 
         desktopPassword = KStringHandler::obscure(krfbConfig.readEntry(
                 "desktopPassword", QString()));
